{% set plot_titles = [
"camera_averaged_FF_Q",
"camera_averaged_FF_Q_std",
"camera_averaged_FF_time",
"camera_averaged_FF_time_std",
"camera_averaged_FF_rel_pixel_time_std",
] %}

{% extends "templates/base.html" %}

{% import "macros/plot_grid.html" as plot_macros %}
{% import "macros/extra_js.html" as add_js_macros %}
{% import "macros/extra_css.html" as add_css_macros %}

{% block title %}
QP: {{ array_element }} {{
subitem }}
{% endblock %}

{% block extra_css %}
{{ add_css_macros.add_css(['badger']) }}
{% endblock %}

{% block content %}
{{ plot_macros.plot_grid(array_element, subitem, active_subitem, 1, 5, plot_titles, 3) }}
{% endblock %}

{% block extra_js %}
{{ add_js_macros.add_js(['d3']) }}
{% endblock %}
