{% extends "templates/base.html" %}

{% block title %}QP: Home{% endblock %}

{% block content %}
<div id="page-content-wrapper">
  <div class="container-flex px-3 xyz">
    <h1>Welcome to QualPipe GUI!</h1>
    <h4>
      This is the basic QualPipe Dashboard {{ array_element }} page
      <i>(just config pourposes)</i>
    </h4>
    <p>
      It is currently empty, but here we will likely put the summary results for a
      preselcted telescope (e.g LST-1) for the past night (if data are available),
      or the Data Quality Report info for a given user selection.
    </p>
  </div>
</div>
{% endblock %}
