{% extends "templates/base.html" %} {% block title %}QP: Page Not Found{% endblock
%} {% block content %}
<div class="container">
  <h1>404 - Page Not Found</h1>
  <p>Oops, this page doesn't exist!</p>
  <a href="/home" class="btn btn-primary">Go back Home</a>
</div>
{% endblock %}
