.nav-pills > li > a {
  border-radius: 0; }

#sidebar-wrapper {
  z-index: 1000;
  position: fixed;
  left: 250px;
  width: 250px;
  height: 100%;
  margin-left: -250px;
  overflow-y: scroll;
  background: #0066cc;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  -o-transition: all 0.5s ease;
  transition: all 0.5s ease;
  background-image: url("/static/images/sidebar-bg.jpg");
  background-size: cover; }

#sidebar-wrapper ul li a span.fa-stack {
  min-width: 50px;
  padding: 0 10px; }

#sidebar-wrapper ul li a select {
  width: 70%; }

#sidebar-wrapper ul li a input {
  width: 70%; }

#sidebar-wrapper ul li a button {
  width: 70%;
  font-weight: bold !important; }

#page-content-wrapper {
  padding: 20px;
  position: relative;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  -o-transition: all 0.5s ease;
  transition: all 0.5s ease; }

.xyz {
  min-width: 360px; }

.sidebar-nav {
  position: absolute;
  top: 0;
  width: 250px;
  margin: 0;
  padding: 0;
  list-style: none;
  margin-top: 2px; }

.sidebar-nav li {
  line-height: 40px; }

.sidebar-nav li a {
  display: block;
  text-decoration: none;
  color: #fff; }

.sidebar-nav li a:hover {
  text-decoration: none;
  color: #fff;
  background: rgba(255, 255, 255, 0.2);
  border-left: #99c2ff 4px solid; }

.sidebar-nav li a:active,
.sidebar-nav li a:focus {
  text-decoration: none; }

#wrapper {
  padding-left: 250px; }

#wrapper.collapsed #sidebar-wrapper {
  width: 50px; }

#wrapper.collapsed #sidebar-wrapper:hover {
  width: 250px; }

#wrapper.collapsed #page-content-wrapper {
  position: relative;
  margin-right: 0;
  margin-left: -200px;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  -o-transition: all 0.5s ease;
  transition: all 0.5s ease;
  width: auto; }

.form-control {
  color: #0066cc;
  background-color: #99c2ff;
  border: 1px solid #80bfff;
  border-radius: 5px;
  -webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  -o-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s; }

#date-picker {
  margin-top: 2px;
  margin-left: 4px;
  margin-right: 4px;
  margin-bottom: 0px; }

.datepicker.datepicker-dropdown.dropdown-menu {
  background-color: #99c2ff;
  border: 1px solid #3399ff;
  color: #0066cc;
  z-index: 1040 !important; }

.datepicker-days > table > tfoot > tr > th.today {
  background-color: #3399ff;
  border: 1px solid #80bfff;
  border-radius: 4px; }

.datepicker-days > table > tfoot > tr > th.today:hover {
  background-color: #4d94e6; }

.datepicker-days > table > tfoot > tr > th.clear {
  background-color: #3399ff;
  border: 1px solid #80bfff;
  border-radius: 4px; }

.datepicker-days > table > tfoot > tr > th.clear:hover {
  background-color: #4d94e6; }

/* Remove focus outline and background for select and option */
.no-focus:focus {
  background-color: #99c2ff;
  color: #0066cc; }

.no-focus option:focus {
  background-color: #99c2ff;
  color: #0066cc; }
