.scatterPlot-title {
  fill: #0066cc;
  font: bold 16px sans-serif;
  text-anchor: middle; }

.scatterPlot-xlabel {
  fill: #000;
  font: 12px sans-serif;
  text-anchor: middle; }

.scatterPlot-ylabel {
  fill: #000;
  font: 12px sans-serif;
  text-anchor: middle; }

.scatterPlot-line {
  fill: none;
  stroke: #0066cc;
  stroke-width: 2px; }

.scatterPlot-line-dashed {
  stroke-dasharray: 5, 5; }

.scatterPlot-line-dotted {
  stroke-dasharray: 2, 8; }

.scatterPlot-line-dot-dashed {
  stroke-dasharray: 6, 3, 2, 3; }

.scatterPlot-line-dot-dashed-dashed {
  stroke-dasharray: 6, 3, 2, 3, 6, 3; }

.scatterPlot-point {
  fill: #007bff;
  stroke: #fff;
  stroke-width: 1px; }

.scatterPlot-xerror,
.scatterPlot-yerror {
  stroke: #3399ff;
  stroke-width: 1px; }
