@import "color";

.footer {
  background-color: $tertiary;
  padding: 10px 20px;
  align-items: center;
  min-height: 32px;
}

.footer > div > div > nav > ol {
  padding: 0px 0px;
  background-color: $tertiary;
  li {
    a {
      color: #00f;
    }
  }
}

.footer .row,
.footer .col-4,
.footer .col-8 {
  margin: 0;
  padding: 0;
}

.footer .breadcrumb {
  margin-bottom: 0;
  padding: 0.1rem 0.3rem;
  background: none;
}
