{% extends "templates/base.html" %}

{% block title %}QP: Work in Progress{% endblock %}

{% block content %}
<div id="page-content-wrapper">
  <div class="container-flex px-3 xyz text-center">
    <h1>501 - Not Implemented Yet</h1>
    <p>Oops, this page doesn't exist yet!</p>
    <img class="WIP" alt="WIP" src="/static/images/WIP.png" />
    <p>&nbsp</p>
    <a href="/home" class="btn btn-primary">Go back Home</a>
  </div>
</div>
{% endblock %}
