.logo-navbar {
  width: 100px; }

.nav-item {
  border: 2px solid #007bff; }

.nav-item:hover {
  background-color: #0066cc;
  border: 2px solid #0066cc;
  border-radius: 6px 6px; }

.nav-item.active {
  border: 2px solid #3399ff;
  border-radius: 6px 6px;
  background-color: #0066cc;
  box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.2); }

.first-nav div ul li.nav-separator {
  border: 1px solid #3399ff; }

.second-nav div ul li.nav-separator {
  border: 1px solid #80bfff; }

.first-nav {
  overflow-x: scroll;
  min-height: 60px;
  background-color: #007bff; }

.second-nav {
  overflow-x: scroll;
  background-color: #3399ff;
  top: 60px; }

.navbar div ul li a {
  color: white !important; }

.nav-subitem {
  border: 2px solid #3399ff; }

.nav-subitem:hover {
  background-color: #4d94e6;
  border: 2px solid #4d94e6;
  border-radius: 6px 6px; }

.nav-subitem.active {
  border: 2px solid #80bfff;
  border-radius: 6px 6px;
  background-color: #4d94e6;
  box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.1); }

#navbarToggler,
#navbarToggler2 {
  overflow-y: scroll; }

.WIP {
  height: 300px; }
