$primary: #007bff;
$secondary: #3399ff;
$tertiary: #80bfff;
$quaternary: #0066cc;
$quinary: #4d94e6;
$senary: #99c2ff;
$septenary: #ddecfd;

// gray scale for dark mode TBD
// $primary: #343a40;
// $secondary: #808080;
// $tertiary: #c0c0c0;
// $quaternary: #303030;
// $quinary: #707070;
// $senary: #a0a0a0;
// $septenary: #e0e0e0;
